Play and Record Sound with Python
=================================

This Python_ module provides bindings for the PortAudio_ library and a few
convenience functions to play and record NumPy_ arrays containing audio signals.

The ``sounddevice`` module is available for Linux, macOS and Windows.

Documentation:
   https://python-sounddevice.readthedocs.io/

Source code repository and issue tracker:
   https://github.com/spatialaudio/python-sounddevice/

License:
   MIT -- see the file ``LICENSE`` for details.

.. _Python: https://www.python.org/
.. _PortAudio: http://www.portaudio.com/
.. _NumPy: https://numpy.org/
